package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.cache.Grade;
import com.datacloudsec.scan.cache.Grade2;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.GradeMapper;
import com.datacloudsec.scan.dao.ReportMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IGrade;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.EntryResult;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SystemUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/GradeService.class */
public class GradeService implements IGrade {
    private GradeMapper gradeMapper = (GradeMapper) InstanceUtil.newDaoInstance(GradeMapper.class);
    private ReportMapper reportMapper = (ReportMapper) InstanceUtil.newDaoInstance(ReportMapper.class);

    public void importCjb(HttpSession session, FileItem file) throws Exception {
        File f = SystemUtil.uploadFile(file, Constant.TEMP_DIR, (String) null);
        InputStream is = null;
        try {
            is = new FileInputStream(f);
            XSSFWorkbook hssfWorkbook = new XSSFWorkbook(is);
            IOUtils.closeQuietly(is);
            Map<String, String> infosys = readXlsx(hssfWorkbook.getSheetAt(0), 1, 7);
            if (infosys.containsKey("被测对象名称*")) {
                importCjb2(session, hssfWorkbook);
            } else {
                importCjb1(session, hssfWorkbook);
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(is);
            throw th;
        }
    }

    public File uploadTop(FileItem file, Integer sysid, Integer type, Integer version) throws Exception {
        if (file.getSize() > 512000) {
            throw new UEException("文件不能大于500K");
        }
        File tmpFile = SystemUtil.uploadFile(file, Constant.TEMP_DIR, (String) null);
        BufferedImage img = ImageIO.read(tmpFile);
        String filename = null;
        if (type.intValue() == 0) {
            filename = "nettop.png";
        } else if (type.intValue() == 1) {
            filename = "tooltop.png";
        }
        File f = new File(Constant.COMMON_DIR, String.valueOf((version == null || version.intValue() != 2) ? "grade" : "grade2") + "/" + sysid + "/" + filename);
        File dir = f.getParentFile();
        if (!dir.isDirectory()) {
            dir.mkdirs();
        }
        FileOutputStream os = new FileOutputStream(f);
        try {
            ImageIO.write(img, "png", os);
            return f;
        } finally {
            IOUtils.closeQuietly(os);
        }
    }

    public int queryCount(HttpSession session, String name, String sag, String uname) throws Exception {
        return this.gradeMapper.queryCount(name, sag, uname, DataRule.getRuleWhere(session, "t_infosys"));
    }

    public List<Map<String, Object>> query(HttpSession session, String name, String sag, String uname, Integer offset, Integer limit) throws Exception {
        return this.gradeMapper.query(name, sag, uname, offset, limit, DataRule.getRuleWhere(session, "t_infosys"));
    }

    public int query2Count(HttpSession session, String name, String sag, String uname) throws Exception {
        return this.gradeMapper.query2Count(name, sag, uname, DataRule.getRuleWhere(session, "t_infosys2"));
    }

    public List<Map<String, Object>> query2(HttpSession session, String name, String sag, String uname, Integer offset, Integer limit) throws Exception {
        return this.gradeMapper.query2(name, sag, uname, offset, limit, DataRule.getRuleWhere(session, "t_infosys2"));
    }

    public int searchHydwCount(HttpSession session, Integer type, String name) throws Exception {
        return this.gradeMapper.searchHydwCount(type, name, DataRule.getRuleWhere(session, "t_hydw"));
    }

    public List<Map<String, Object>> searchHydw(HttpSession session, Integer type, String name, Integer offset, Integer limit) throws Exception {
        return this.gradeMapper.searchHydw(type, name, offset, limit, DataRule.getRuleWhere(session, "t_hydw"));
    }

    public int queryDevmgCount(HttpSession session) throws Exception {
        return this.gradeMapper.queryDevmgCount(DataRule.getRuleWhere(session, "t_device"));
    }

    public List<Map<String, Object>> queryDevmg(HttpSession session, Integer offset, Integer limit) throws Exception {
        return this.gradeMapper.queryDevmg(offset, limit, DataRule.getRuleWhere(session, "t_device"));
    }

    @Transactional
    public void addDev(HttpServletRequest req, Integer sysid, String type) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("sysid", sysid);
        params.put("type", type);
        params.put("ischeck", Integer.valueOf(ObjectUtil.getInt(req.getParameter("ischeck"), 0)));
        Map<String, String[]> entry = new HashMap<>();
        entry.put("机房", new String[]{"host_name", "host_location", "host_impo"});
        entry.put("安全设备", new String[]{"net_ip", "net_name", "net_os", "net_brand", "net_type", "net_use", "net_impo"});
        entry.put("网络设备", new String[]{"net_ip", "net_name", "net_os", "net_brand", "net_type", "net_use", "net_impo"});
        entry.put("服务器/存储设备", new String[]{"ser_ip", "ser_name", "ser_os", "ser_ver", "ser_soft", "ser_impo"});
        entry.put("终端", new String[]{"term_ip", "term_name", "term_os", "term_use", "term_impo"});
        entry.put("业务应用软件", new String[]{"soft_ip", "soft_name", "soft_func", "soft_fact", "soft_impo"});
        entry.put("数据库管理系统", new String[]{"dbsys_ip", "dbsys_name", "dbsys_type", "dbsys_devname", "dbsys_impo"});
        entry.put("关键数据类别", new String[]{"data_type", "data_app", "data_secu", "data_impo"});
        entry.put("安全相关人员", new String[]{"user_name", "user_job", "user_concat"});
        entry.put("安全管理文档", new String[]{"doc_name", "doc_content"});
        entry.put("访谈人员", new String[]{"interv_name", "interv_job"});
        String[] fields = entry.get(type);
        if (fields == null) {
            throw new UEException("资产类型错误");
        }
        for (String field : fields) {
            if (field.contains("_impo")) {
                params.put(field, Integer.valueOf(ObjectUtil.getInt(req.getParameter(field), 3)));
            } else {
                params.put(field, req.getParameter(field));
            }
        }
        this.gradeMapper.addDev(params);
        String layer = (String) LAYER_ENTRY.get(type);
        if (layer != null) {
            Integer devid = ObjectUtil.getInt(params.get("id"));
            String sag = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
            this.gradeMapper.createInfosysItems(sysid, sag, devid, layer);
        }
    }

    @Transactional
    public void addDev2(HttpServletRequest req, Integer sysid, String type) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("sysid", sysid);
        params.put("type", type);
        Map<String, String[]> entry = new HashMap<>();
        entry.put("物理机房", new String[]{"host_name", "host_location", "host_impo"});
        entry.put("安全设备", new String[]{"net_ip", "net_name", "net_isvir", "net_os", "net_brand", "net_use", "net_impo"});
        entry.put("网络设备", new String[]{"net_ip", "net_name", "net_isvir", "net_os", "net_brand", "net_use", "net_impo"});
        entry.put("服务器/存储设备", new String[]{"ser_ip", "ser_name", "ser_ptname", "ser_isvir", "ser_os", "ser_dbsys", "ser_mld", "ser_desct", "ser_impo"});
        entry.put("终端/现场设备", new String[]{"term_ip", "term_name", "term_isvir", "term_os", "term_soft", "term_desct", "term_impo"});
        entry.put("系统管理软件/平台", new String[]{"soft_name", "soft_devname", "soft_version", "soft_func", "soft_desct", "soft_impo"});
        entry.put("业务应用软件/平台", new String[]{"app_name", "app_func", "app_soft", "app_compnay", "app_impo"});
        entry.put("关键数据类别", new String[]{"data_type", "data_level", "data_app", "data_secu", "data_impo"});
        entry.put("安全相关人员", new String[]{"user_name", "user_job", "user_concat"});
        entry.put("安全管理文档", new String[]{"doc_name", "doc_content"});
        String[] fields = entry.get(type);
        if (fields == null) {
            throw new UEException("资产类型错误");
        }
        for (String field : fields) {
            if (field.contains("_impo")) {
                params.put(field, Integer.valueOf(ObjectUtil.getInt(req.getParameter(field), 3)));
            } else {
                params.put(field, StringUtils.join(req.getParameterValues(field), "/"));
            }
        }
        this.gradeMapper.addDev2(params);
        String layer = (String) LAYER_ENTRY2.get(type);
        if (layer != null) {
            Integer devid = ObjectUtil.getInt(params.get("id"));
            Map<String, Object> data = this.gradeMapper.getById2(sysid);
            String sag = String.valueOf(data.get("sag"));
            int ext_cloud = ObjectUtil.getInt(data.get("ext_cloud"), 0);
            int ext_mobile = ObjectUtil.getInt(data.get("ext_mobile"), 0);
            int ext_iot = ObjectUtil.getInt(data.get("ext_iot"), 0);
            int ext_ic = ObjectUtil.getInt(data.get("ext_ic"), 0);
            this.gradeMapper.createInfosys2Items(sysid, sag, devid, layer, Boolean.valueOf(ext_cloud == 1), Boolean.valueOf(ext_mobile == 1), Boolean.valueOf(ext_iot == 1), Boolean.valueOf(ext_ic == 1));
        }
    }

    public void updDev(HttpServletRequest req, Integer id) throws Exception {
        Map<String, Object> device = this.gradeMapper.getDevById(id);
        Map<String, Object> params = new HashMap<>();
        params.put("id", id);
        params.put("ischeck", Integer.valueOf(ObjectUtil.getInt(req.getParameter("ischeck"), 0)));
        Map<String, String[]> entry = new HashMap<>();
        entry.put("机房", new String[]{"host_name", "host_location", "host_impo"});
        entry.put("安全设备", new String[]{"net_ip", "net_name", "net_os", "net_brand", "net_type", "net_use", "net_impo"});
        entry.put("网络设备", new String[]{"net_ip", "net_name", "net_os", "net_brand", "net_type", "net_use", "net_impo"});
        entry.put("服务器/存储设备", new String[]{"ser_ip", "ser_name", "ser_os", "ser_ver", "ser_soft", "ser_impo"});
        entry.put("终端", new String[]{"term_ip", "term_name", "term_os", "term_use", "term_impo"});
        entry.put("业务应用软件", new String[]{"soft_ip", "soft_name", "soft_func", "soft_fact", "soft_impo"});
        entry.put("数据库管理系统", new String[]{"dbsys_ip", "dbsys_name", "dbsys_type", "dbsys_devname", "dbsys_impo"});
        entry.put("关键数据类别", new String[]{"data_type", "data_app", "data_secu", "data_impo"});
        entry.put("安全相关人员", new String[]{"user_name", "user_job", "user_concat"});
        entry.put("安全管理文档", new String[]{"doc_name", "doc_content"});
        entry.put("访谈人员", new String[]{"interv_name", "interv_job"});
        String type = ObjectUtil.getString(device.get("type"), "");
        String[] fields = entry.get(type);
        if (fields == null) {
            throw new UEException("资产类型错误");
        }
        for (String field : fields) {
            if (field.contains("_impo")) {
                params.put(field, Integer.valueOf(ObjectUtil.getInt(req.getParameter(field), 3)));
            } else {
                params.put(field, req.getParameter(field));
            }
        }
        params.put("type", type);
        this.gradeMapper.updDev(params);
    }

    public void updDev2(HttpServletRequest req, Integer id) throws Exception {
        Map<String, Object> device = this.gradeMapper.getDevById2(id);
        Map<String, Object> params = new HashMap<>();
        params.put("id", id);
        Map<String, String[]> entry = new HashMap<>();
        entry.put("物理机房", new String[]{"host_name", "host_location", "host_impo"});
        entry.put("安全设备", new String[]{"net_ip", "net_name", "net_isvir", "net_os", "net_brand", "net_use", "net_impo"});
        entry.put("网络设备", new String[]{"net_ip", "net_name", "net_isvir", "net_os", "net_brand", "net_use", "net_impo"});
        entry.put("服务器/存储设备", new String[]{"ser_ip", "ser_name", "ser_ptname", "ser_isvir", "ser_os", "ser_dbsys", "ser_mld", "ser_desct", "ser_impo"});
        entry.put("终端/现场设备", new String[]{"term_ip", "term_name", "term_isvir", "term_os", "term_soft", "term_desct", "term_impo"});
        entry.put("系统管理软件/平台", new String[]{"soft_name", "soft_devname", "soft_version", "soft_func", "soft_desct", "soft_impo"});
        entry.put("业务应用软件/平台", new String[]{"app_name", "app_func", "app_compnay", "app_soft", "app_impo"});
        entry.put("关键数据类别", new String[]{"data_type", "data_level", "data_app", "data_secu", "data_impo"});
        entry.put("安全相关人员", new String[]{"user_name", "user_job", "user_concat"});
        entry.put("安全管理文档", new String[]{"doc_name", "doc_content"});
        String type = ObjectUtil.getString(device.get("type"), "");
        String[] fields = entry.get(type);
        if (fields == null) {
            throw new UEException("资产类型错误");
        }
        for (String field : fields) {
            if (field.contains("_impo")) {
                params.put(field, Integer.valueOf(ObjectUtil.getInt(req.getParameter(field), 3)));
            } else {
                params.put(field, StringUtils.join(req.getParameterValues(field), "/"));
            }
        }
        params.put("type", type);
        this.gradeMapper.updDev2(params);
    }

    public int queryDevCount(Integer sysid, String type) throws Exception {
        return this.gradeMapper.queryDevCount(sysid, type);
    }

    public List<Map<String, Object>> queryDev(Integer sysid, String type, Integer offset, Integer limit) throws Exception {
        return this.gradeMapper.queryDev(sysid, type, offset, limit);
    }

    public int queryDev2Count(Integer sysid, String type) throws Exception {
        return this.gradeMapper.queryDev2Count(sysid, type);
    }

    public List<Map<String, Object>> queryDev2(Integer sysid, String type, Integer offset, Integer limit) throws Exception {
        return this.gradeMapper.queryDev2(sysid, type, offset, limit);
    }

    public Map<String, Object> getDevById(Integer id) throws Exception {
        return this.gradeMapper.getDevById(id);
    }

    public Map<String, Object> getDevById2(Integer id) throws Exception {
        return this.gradeMapper.getDevById2(id);
    }

    public Map<String, Object> getById(Integer sysid) throws Exception {
        return this.gradeMapper.getById(sysid);
    }

    public Map<String, Object> getById2(Integer sysid) throws Exception {
        return this.gradeMapper.getById2(sysid);
    }

    public Map<String, Object> getByIdHydw(Integer id) throws Exception {
        return this.gradeMapper.getByIdHydw(id);
    }

    public List<String> getHydwLayers(Integer itemtype) throws Exception {
        return this.gradeMapper.getHydwLayers(itemtype);
    }

    public List<String> getCustomLayers(Integer taskid) throws Exception {
        return this.gradeMapper.getCustomLayers(taskid);
    }

    public Map<String, Object> getResultById(Integer id) throws Exception {
        return this.gradeMapper.getResultById(id);
    }

    public Map<String, Object> getResultById2(Integer id) throws Exception {
        return this.gradeMapper.getResultById2(id);
    }

    public Map<String, Object> getResultByIdHydw(Integer id) throws Exception {
        return this.gradeMapper.getResultByIdHydw(id);
    }

    public int updResult(Integer id, String result, Integer score, String desct) throws Exception {
        return this.gradeMapper.updResult(id, result, score, desct, (String) null);
    }

    public int updResult2(Integer id, String result, Integer score, String desct) throws Exception {
        return this.gradeMapper.updResult2(id, result, score, desct, (String) null);
    }

    public int updResultHydw(Integer id, String fillresult, Integer selectresult, String desct) throws Exception {
        return this.gradeMapper.updResultHydw(id, fillresult, selectresult, desct, (String) null);
    }

    @Transactional
    public Integer add(String name, String sag, String uname, String desct, String business, String preeval, Integer uid) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("sysname", name);
        params.put("sag", sag);
        params.put("compname", uname);
        params.put("sysdesc", desct);
        params.put("business", business);
        params.put("preeval", preeval);
        params.put("uid", uid);
        this.gradeMapper.add(params);
        Integer sysid = ObjectUtil.getInt(params.get("id"));
        for (String layer : new String[]{"数据安全及备份恢复", "安全管理制度", "安全管理机构", "人员安全管理", "系统建设管理", "系统运维管理"}) {
            this.gradeMapper.createInfosysItems(sysid, sag, (Integer) null, layer);
        }
        return sysid;
    }

    @Transactional
    public Integer add2(String name, String sag, String uname, String desct, String business, String preeval, Integer ext_cloud, Integer ext_mobile, Integer ext_iot, Integer ext_ic, Integer ext_bdata, Integer ext_other, Integer uid) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("sysname", name);
        params.put("sag", sag);
        params.put("compname", uname);
        params.put("sysdesc", desct);
        params.put("business", business);
        params.put("preeval", preeval);
        params.put("uid", uid);
        params.put("ext_cloud", Integer.valueOf(ext_cloud == null ? 0 : ext_cloud.intValue()));
        params.put("ext_mobile", Integer.valueOf(ext_mobile == null ? 0 : ext_mobile.intValue()));
        params.put("ext_iot", Integer.valueOf(ext_iot == null ? 0 : ext_iot.intValue()));
        params.put("ext_ic", Integer.valueOf(ext_ic == null ? 0 : ext_ic.intValue()));
        params.put("ext_bdata", Integer.valueOf(ext_bdata == null ? 0 : ext_bdata.intValue()));
        params.put("ext_other", Integer.valueOf(ext_other == null ? 0 : ext_other.intValue()));
        this.gradeMapper.add2(params);
        Integer sysid = ObjectUtil.getInt(params.get("id"));
        for (String layer : new String[]{"安全管理制度", "安全管理机构", "安全管理人员", "安全建设管理", "安全运维管理", "安全通信网络", "安全区域边界", "安全管理中心"}) {
            this.gradeMapper.createInfosys2Items(sysid, sag, (Integer) null, layer, Boolean.valueOf(ext_cloud != null && ext_cloud.intValue() == 1), Boolean.valueOf(ext_mobile != null && ext_mobile.intValue() == 1), Boolean.valueOf(ext_iot != null && ext_iot.intValue() == 1), Boolean.valueOf(ext_ic != null && ext_ic.intValue() == 1));
        }
        return sysid;
    }

    public Integer addHydw(Integer type, String name, String compname, Integer itemtype, String desct, Integer uid) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("type", type);
        params.put("name", name);
        params.put("compname", compname);
        params.put("itemtype", itemtype);
        params.put("desct", desct);
        params.put("uid", uid);
        this.gradeMapper.addHydw(params);
        Integer taskid = ObjectUtil.getInt(params.get("id"));
        this.gradeMapper.createHydwItems(taskid, itemtype);
        return taskid;
    }

    @Transactional
    public Integer addCustom(Integer type, String name, String compname, String items, String desct, Integer uid) throws Exception {
        try {
            List<?> itemsList = (List) JsonUtil.MAPPER.readValue(items, List.class);
            Map<String, Object> params = new HashMap<>();
            params.put("type", type);
            params.put("name", name);
            params.put("compname", compname);
            params.put("itemsList", itemsList);
            params.put("desct", desct);
            params.put("uid", uid);
            this.gradeMapper.addHydw(params);
            Integer taskid = ObjectUtil.getInt(params.get("id"));
            this.gradeMapper.addCustomeItems(taskid, itemsList);
            this.gradeMapper.createCustomeItems(taskid);
            return taskid;
        } catch (Exception e) {
            throw new UEException("检查指标格式错误", e);
        }
    }

    public void upd(Integer id, String name, String uname, String desct, String business, String preeval) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("id", id);
        params.put("sysname", name);
        params.put("compname", uname);
        params.put("sysdesc", desct);
        params.put("business", business);
        params.put("preeval", preeval);
        this.gradeMapper.upd(params);
    }

    public void upd2(Integer id, String name, String uname, String desct, String business, String preeval) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("id", id);
        params.put("sysname", name);
        params.put("compname", uname);
        params.put("sysdesc", desct);
        params.put("business", business);
        params.put("preeval", preeval);
        this.gradeMapper.upd2(params);
    }

    public void updHydw(Integer id, String name, String compname, String desct) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("id", id);
        params.put("name", name);
        params.put("compname", compname);
        params.put("desct", desct);
        this.gradeMapper.updHydw(params);
    }

    public List<Map<String, Object>> getInfosysCheckResult(Integer sysid, Integer devid, String layer) throws Exception {
        return this.gradeMapper.getInfosysCheckResult(sysid, (Boolean) null, devid, layer);
    }

    public List<Map<String, Object>> getInfosys2CheckResult(Integer sysid, Integer devid, String layer) throws Exception {
        return this.gradeMapper.getInfosys2CheckResult(sysid, (Boolean) null, devid, layer);
    }

    public List<Map<String, Object>> getInfosysHydwCheckResult(Integer id, String layer) throws Exception {
        return this.gradeMapper.getInfosysHydwCheckResult(id, layer);
    }

    public List<Map<String, Object>> getInfosysCustomCheckResult(Integer id, String layer) throws Exception {
        return this.gradeMapper.getInfosysCustomCheckResult(id, layer);
    }

    public void uploadFile(FileItem file, Integer sysid, Integer id) throws Exception {
        Map<String, Object> result = getResultById(id);
        String deviceid = ObjectUtil.getString(result.get("deviceid"), "layer");
        File destDir = new File(Constant.COMMON_DIR, "grade/" + sysid + "/" + deviceid);
        SystemUtil.uploadFile(file, destDir, new StringBuilder().append(id).toString());
        this.gradeMapper.updResult(id, (String) null, (Integer) null, (String) null, file.getName());
    }

    public void uploadFile2(FileItem file, Integer sysid, Integer id) throws Exception {
        Map<String, Object> result = getResultById2(id);
        String deviceid = ObjectUtil.getString(result.get("deviceid"), "layer");
        File destDir = new File(Constant.COMMON_DIR, "grade2/" + sysid + "/" + deviceid);
        SystemUtil.uploadFile(file, destDir, new StringBuilder().append(id).toString());
        this.gradeMapper.updResult2(id, (String) null, (Integer) null, (String) null, file.getName());
    }

    public void uploadFileHydw(FileItem file, Integer sysid, Integer id) throws Exception {
        File destDir = new File(Constant.COMMON_DIR, "grade-hydw/" + sysid);
        SystemUtil.uploadFile(file, destDir, new StringBuilder().append(id).toString());
        this.gradeMapper.updResultHydw(id, (String) null, (Integer) null, (String) null, file.getName());
    }

    public void delFile(Integer sysid, Integer id) throws Exception {
        Map<String, Object> result = getResultById(id);
        String deviceid = ObjectUtil.getString(result.get("deviceid"), "layer");
        File destFile = new File(Constant.COMMON_DIR, "grade/" + sysid + "/" + deviceid + "/" + id);
        destFile.delete();
        this.gradeMapper.updResult(id, (String) null, (Integer) null, (String) null, "");
    }

    public void delFile2(Integer sysid, Integer id) throws Exception {
        Map<String, Object> result = getResultById2(id);
        String deviceid = ObjectUtil.getString(result.get("deviceid"), "layer");
        File destFile = new File(Constant.COMMON_DIR, "grade2/" + sysid + "/" + deviceid + "/" + id);
        destFile.delete();
        this.gradeMapper.updResult2(id, (String) null, (Integer) null, (String) null, "");
    }

    public void delFileHydw(Integer sysid, Integer id) throws Exception {
        File destFile = new File(Constant.COMMON_DIR, "grade-hydw/" + sysid + "/" + id);
        destFile.delete();
        this.gradeMapper.updResultHydw(id, (String) null, (Integer) null, (String) null, "");
    }

    public List<Map<String, Object>> getTreeDev(Integer sysid) throws Exception {
        return this.gradeMapper.getTreeDev(sysid);
    }

    public List<Map<String, Object>> getTreeDev2(Integer sysid) throws Exception {
        return this.gradeMapper.getTreeDev2(sysid);
    }

    @Transactional
    public void del(Integer infosysid, Integer version) throws Exception {
        Integer rcount = Integer.valueOf(this.gradeMapper.del(infosysid, version));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        this.gradeMapper.delTaskDev(infosysid);
        this.gradeMapper.delTaskResult(infosysid);
        this.gradeMapper.delCustomeItem(infosysid);
        File destDir = new File(Constant.COMMON_DIR, "grade/" + infosysid);
        FileUtils.deleteDirectory(destDir);
    }

    @Transactional
    public void del2(Integer infosysid, Integer version) throws Exception {
        Integer rcount = Integer.valueOf(this.gradeMapper.del2(infosysid, version));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        this.gradeMapper.del2TaskDev(infosysid);
        this.gradeMapper.del2TaskResult(infosysid);
        this.gradeMapper.del2ScanResult(infosysid);
        File destDir = new File(Constant.COMMON_DIR, "grade2/" + infosysid);
        FileUtils.deleteDirectory(destDir);
    }

    @Transactional
    public void delHydw(Integer infosysid) throws Exception {
        this.gradeMapper.delHydw(infosysid);
        this.gradeMapper.delHydwTaskResult(infosysid);
        File destDir = new File(Constant.COMMON_DIR, "grade-hydw/" + infosysid);
        FileUtils.deleteDirectory(destDir);
    }

    @Transactional
    public void delDev(Integer sysid, Integer id, Integer version) throws Exception {
        Integer rcount = Integer.valueOf(this.gradeMapper.delDev(id, version));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        this.gradeMapper.delResult(id);
        File destDir = new File(Constant.COMMON_DIR, "grade/" + sysid + "/" + id);
        FileUtils.deleteDirectory(destDir);
    }

    @Transactional
    public void delDev2(Integer sysid, Integer id, Integer version) throws Exception {
        Integer rcount = Integer.valueOf(this.gradeMapper.delDev2(id, version));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        this.gradeMapper.delResult2(id);
        File destDir = new File(Constant.COMMON_DIR, "grade2/" + sysid + "/" + id);
        FileUtils.deleteDirectory(destDir);
    }

    public void saveData(Integer sysid, String name, String value) throws Exception {
        this.gradeMapper.saveData(sysid, name, value);
    }

    public List<Map<String, Object>> getData(Integer sysid) throws Exception {
        return this.gradeMapper.getData(sysid);
    }

    public List<Map<String, Object>> relist(Integer sysid) throws Exception {
        List<Map<String, Object>> devlist = this.gradeMapper.relist(sysid);
        return devlist;
    }

    public List<Map<String, Object>> relist2(Integer sysid) throws Exception {
        List<Map<String, Object>> devlist = this.gradeMapper.relist2(sysid);
        return devlist;
    }

    public int[] autoRe(String values, Integer sysid) throws Exception {
        boolean accord;
        int[] nums = new int[2];
        List<Map<String, Object>> devlist = new ArrayList<>();
        for (String arr : values.split(",")) {
            String[] arrs = arr.split("/");
            if (arrs.length >= 4) {
                int scanDevid = ObjectUtil.getInt(arrs[2], 0);
                Map<String, Object> row = new HashMap<>();
                row.put("gradeid", arrs[0]);
                row.put("taskType", arrs[1]);
                row.put("scanDevid", Integer.valueOf(scanDevid));
                row.put("type", arrs[3]);
                row.put("confContent", this.gradeMapper.getTaskDevConf(Integer.valueOf(scanDevid)));
                devlist.add(row);
            }
        }
        Map<String, Map<String, List<Map<String, Object>>>> devEntry = EntryResult.parseEntryEntry(devlist, "gradeid", "taskType", new String[]{"scanDevid", "type", "confContent"});
        Map<String, List<Grade.Item>> items = Grade.getInstance().getItems();
        for (Map.Entry<String, Map<String, List<Map<String, Object>>>> entry : devEntry.entrySet()) {
            Integer gradeDevid = Integer.valueOf(ObjectUtil.getInt(entry.getKey(), 0));
            Map<String, List<Map<String, Object>>> value = entry.getValue();
            List<Map<String, Object>> list = this.gradeMapper.getInfosysCheckResult(sysid, true, gradeDevid, (String) null);
            if (list.size() > 0) {
                nums[0] = nums[0] + 1;
                for (Map<String, Object> row2 : list) {
                    String klgeid = ObjectUtil.getString(row2.get("klgeid"), (String) null);
                    List<Grade.Item> itemList = items.get(klgeid);
                    if (itemList != null) {
                        Map<Integer, Boolean> accords = new HashMap<>();
                        Set<String> tools = new HashSet<>();
                        Set<Integer> indexs = new HashSet<>();
                        for (Grade.Item item : itemList) {
                            int type = item.getType().intValue();
                            List<Map<String, Object>> vals = value.get(new StringBuilder(String.valueOf(type)).toString());
                            if (vals != null && vals.size() > 0) {
                                for (Map<String, Object> val : vals) {
                                    if (type != 2 || checkDevType(item, val)) {
                                        Integer scanDevid2 = ObjectUtil.getInt(val.get("scanDevid"));
                                        if (type == 0) {
                                            accord = calcToolResult0(scanDevid2, item.getNames(), item.getNameTypes());
                                        } else if (type == 1) {
                                            accord = calcToolResult1(scanDevid2, item.getNames(), item.getNameTypes());
                                        } else if (type == 2) {
                                            accord = calcToolResult2(scanDevid2, item.getNames());
                                        } else if (type == 3) {
                                            accord = calcToolResult3(scanDevid2);
                                        } else if (type == 4) {
                                            accord = calcToolResult4(scanDevid2, item.getNames(), item.getNameTypes());
                                        } else if (type == 5) {
                                            accord = calcToolResult5(scanDevid2);
                                        } else if (type == 7) {
                                            accord = calcToolResult7(scanDevid2);
                                        }
                                        String toolName = (String) TOOLS.get(new StringBuilder(String.valueOf(type)).toString());
                                        if (toolName != null) {
                                            tools.add(toolName);
                                        }
                                        indexs.add(item.getIndex());
                                        if (accord) {
                                            if (accords.get(item.getIndex()) == null) {
                                                accords.put(item.getIndex(), true);
                                            }
                                        } else {
                                            accords.put(item.getIndex(), false);
                                        }
                                    }
                                }
                            }
                        }
                        if (accords.size() > 0) {
                            nums[1] = nums[1] + accords.size();
                            String desct = "第【" + StringUtils.join(indexs, "、") + "】项已用【" + StringUtils.join(tools, ",") + "】工具检查";
                            saveToolCalcResult(gradeDevid, row2, accords, desct);
                        }
                    }
                }
            }
        }
        return nums;
    }

    public int[] autoRe2(String values, Integer sysid) throws Exception {
        boolean accord;
        int[] nums = new int[2];
        List<Map<String, Object>> devlist = new ArrayList<>();
        String[] valArr = values.split(",");
        for (String arr : valArr) {
            String[] arrs = arr.split("/");
            if (arrs.length >= 4) {
                int scanDevid = ObjectUtil.getInt(arrs[2], 0);
                Map<String, Object> row = new HashMap<>();
                row.put("gradeid", arrs[0]);
                row.put("taskType", arrs[1]);
                row.put("scanDevid", Integer.valueOf(scanDevid));
                row.put("type", arrs[3]);
                row.put("confContent", this.gradeMapper.getTaskDevConf(Integer.valueOf(scanDevid)));
                devlist.add(row);
            }
        }
        Map<String, Map<String, List<Map<String, Object>>>> devEntry = EntryResult.parseEntryEntry(devlist, "gradeid", "taskType", new String[]{"scanDevid", "type", "confContent"});
        Map<String, List<Grade2.Item>> items = Grade2.getInstance().getItems();
        for (Map.Entry<String, Map<String, List<Map<String, Object>>>> entry : devEntry.entrySet()) {
            Integer gradeDevid = Integer.valueOf(ObjectUtil.getInt(entry.getKey(), 0));
            Map<String, List<Map<String, Object>>> value = entry.getValue();
            List<Map<String, Object>> list = this.gradeMapper.getInfosys2CheckResult(sysid, true, gradeDevid, (String) null);
            if (list.size() > 0) {
                nums[0] = nums[0] + 1;
                for (Map<String, Object> row2 : list) {
                    String unit = ObjectUtil.getString(row2.get("unit"), (String) null);
                    List<Grade2.Item> itemList = items.get(unit);
                    if (itemList != null) {
                        Map<Integer, Boolean> accords = new HashMap<>();
                        Set<String> tools = new HashSet<>();
                        Set<Integer> indexs = new HashSet<>();
                        for (Grade2.Item item : itemList) {
                            int type = item.getType().intValue();
                            List<Map<String, Object>> vals = value.get(new StringBuilder(String.valueOf(type)).toString());
                            if (vals != null && vals.size() > 0) {
                                for (Map<String, Object> val : vals) {
                                    if (type != 2 || checkDevType(item, val)) {
                                        Integer scanDevid2 = ObjectUtil.getInt(val.get("scanDevid"));
                                        if (type == 0) {
                                            accord = calcToolResult0(scanDevid2, item.getNames(), item.getNameTypes());
                                        } else if (type == 1) {
                                            accord = calcToolResult1(scanDevid2, item.getNames(), item.getNameTypes());
                                        } else if (type == 2) {
                                            accord = calcToolResult2(scanDevid2, item.getNames());
                                        } else if (type == 3) {
                                            accord = calcToolResult3(scanDevid2);
                                        } else if (type == 4) {
                                            accord = calcToolResult4(scanDevid2, item.getNames(), item.getNameTypes());
                                        } else if (type == 5) {
                                            accord = calcToolResult5(scanDevid2);
                                        } else if (type == 7) {
                                            accord = calcToolResult7(scanDevid2);
                                        }
                                        String toolName = (String) TOOLS.get(new StringBuilder(String.valueOf(type)).toString());
                                        if (toolName != null) {
                                            tools.add(toolName);
                                        }
                                        indexs.add(item.getIndex());
                                        if (accord) {
                                            if (accords.get(item.getIndex()) == null) {
                                                accords.put(item.getIndex(), true);
                                            }
                                        } else {
                                            accords.put(item.getIndex(), false);
                                        }
                                    }
                                }
                            }
                        }
                        if (accords.size() > 0) {
                            nums[1] = nums[1] + accords.size();
                            String desct = "第【" + StringUtils.join(indexs, "、") + "】项已用【" + StringUtils.join(tools, ",") + "】工具检查";
                            saveToolCalcResult2(gradeDevid, row2, accords, desct);
                        }
                    }
                }
            }
        }
        this.gradeMapper.delReResult(sysid);
        for (String arr2 : valArr) {
            String[] arrs2 = arr2.split("/");
            if (arrs2.length >= 4) {
                int scanDevid3 = ObjectUtil.getInt(arrs2[2], 0);
                int gradeid = ObjectUtil.getInt(arrs2[0], 0);
                this.gradeMapper.addReResult(sysid, Integer.valueOf(gradeid), Integer.valueOf(scanDevid3));
            }
        }
        return nums;
    }

    private boolean checkDevType(Grade.Item item, Map<String, Object> val) {
        String devtype = item.getDevtype();
        if (devtype == null) {
            return true;
        }
        Integer devType = ObjectUtil.getInt(val.get("type"));
        if (devtype.contains("netsec") && devType.intValue() == 4) {
            return true;
        }
        if (devtype.contains("securitysec") && devType.intValue() == 6) {
            return true;
        }
        if (devtype.contains("sys") && devType.intValue() == 7) {
            String ostype = item.getOstype();
            if (ostype == null) {
                return true;
            }
            String confContent = ObjectUtil.getString(val.get("confContent"), (String) null);
            if (confContent != null) {
                try {
                    Map<String, Object> conf = (Map) JsonUtil.MAPPER.readValue(confContent, new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.GradeService.1
                    });
                    String assetType = (String) conf.get("assetType");
                    for (String t : ostype.split("/")) {
                        if (assetType.contains(t)) {
                            return true;
                        }
                    }
                    return false;
                } catch (Exception e) {
                    return false;
                }
            }
            return false;
        }
        return false;
    }

    private boolean checkDevType(Grade2.Item item, Map<String, Object> val) {
        String devtype = item.getDevtype();
        if (devtype == null) {
            return true;
        }
        Integer devType = ObjectUtil.getInt(val.get("type"));
        if (devtype.contains("netsec") && devType.intValue() == 4) {
            return true;
        }
        if (devtype.contains("securitysec") && devType.intValue() == 6) {
            return true;
        }
        if (devtype.contains("sys") && devType.intValue() == 7) {
            String ostype = item.getOstype();
            if (ostype == null) {
                return true;
            }
            String confContent = ObjectUtil.getString(val.get("confContent"), (String) null);
            if (confContent != null) {
                try {
                    Map<String, Object> conf = (Map) JsonUtil.MAPPER.readValue(confContent, new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.GradeService.2
                    });
                    String assetType = (String) conf.get("assetType");
                    for (String t : ostype.split("/")) {
                        if (assetType.contains(t)) {
                            return true;
                        }
                    }
                    return false;
                } catch (Exception e) {
                    return false;
                }
            }
            return false;
        }
        return false;
    }

    private void saveToolCalcResult(Integer gradeDevid, Map<String, Object> item, Map<Integer, Boolean> accords, String desct) {
        int itemNum;
        Integer id = ObjectUtil.getInt(item.get("id"));
        String scoref = ObjectUtil.getString(item.get("scoref"), (String) null);
        if (id == null || scoref == null) {
            return;
        }
        if (scoref.contains("/r")) {
            itemNum = scoref.replace("/r", "|").split("\\|").length - 1;
        } else {
            itemNum = scoref.split("\\|").length;
        }
        String result = ObjectUtil.getString(item.get("result"), (String) null);
        String[] entryResult = null;
        if (result != null) {
            entryResult = result.split("\\|");
        }
        List<String> newResult = new ArrayList<>();
        int checkedNum = 0;
        for (int i = 1; i <= itemNum; i++) {
            Boolean b = accords.get(Integer.valueOf(i));
            if (b != null) {
                if (b.booleanValue()) {
                    checkedNum++;
                    newResult.add(ReportService.REPORT_STATE_SUCCESS);
                } else {
                    newResult.add(ReportService.REPORT_STATE_READY);
                }
            } else if (entryResult != null && entryResult.length >= i) {
                String v = entryResult[i - 1];
                newResult.add(v);
                if (v.equals(ReportService.REPORT_STATE_SUCCESS)) {
                    checkedNum++;
                }
            } else {
                newResult.add(ReportService.REPORT_STATE_READY);
            }
        }
        String rule = ObjectUtil.getString(item.get("rule"), (String) null);
        String[] entryRule = null;
        if (rule != null) {
            entryRule = rule.split("\\|");
        }
        Integer score = null;
        if (entryRule != null) {
            String[] strArr = entryRule;
            int length = strArr.length;
            int i2 = 0;
            while (true) {
                if (i2 >= length) {
                    break;
                }
                String r = strArr[i2];
                int index = ObjectUtil.getInt(r, 0) - 1;
                if (index < 0 || index >= newResult.size() || ReportService.REPORT_STATE_SUCCESS.equals(newResult.get(index))) {
                    i2++;
                } else {
                    score = 0;
                    break;
                }
            }
        }
        if (score == null) {
            score = Integer.valueOf((int) Math.round(((checkedNum * 1.0d) / newResult.size()) * 5.0d));
        }
        this.gradeMapper.updResult(id, StringUtils.join(newResult, "|"), score, desct, (String) null);
    }

    private void saveToolCalcResult2(Integer gradeDevid, Map<String, Object> item, Map<Integer, Boolean> accords, String desct) {
        Integer id = ObjectUtil.getInt(item.get("id"));
        String items = ObjectUtil.getString(item.get("items"), (String) null);
        String rule = ObjectUtil.getString(item.get("rule"), (String) null);
        if (id == null || items == null) {
            return;
        }
        int itemNum = items.split("/n").length;
        String result = ObjectUtil.getString(item.get("result"), (String) null);
        String[] entryResult = null;
        if (result != null) {
            entryResult = result.split("\\|");
        }
        List<String> newResult = new ArrayList<>();
        int checkedNum = 0;
        for (int i = 1; i <= itemNum; i++) {
            Boolean b = accords.get(Integer.valueOf(i));
            if (b != null) {
                if (b.booleanValue()) {
                    checkedNum++;
                    newResult.add(ReportService.REPORT_STATE_SUCCESS);
                } else {
                    newResult.add(ReportService.REPORT_STATE_READY);
                }
            } else if (entryResult != null && entryResult.length >= i) {
                String v = entryResult[i - 1];
                newResult.add(v);
                if (v.equals(ReportService.REPORT_STATE_SUCCESS)) {
                    checkedNum++;
                }
            } else {
                newResult.add(ReportService.REPORT_STATE_READY);
            }
        }
        String[] entryRule = null;
        if (rule != null) {
            entryRule = rule.split("\\|");
        }
        Integer score = null;
        if (entryRule != null) {
            String[] strArr = entryRule;
            int length = strArr.length;
            int i2 = 0;
            while (true) {
                if (i2 >= length) {
                    break;
                }
                String r = strArr[i2];
                boolean b2 = true;
                String[] split = r.split(",");
                int length2 = split.length;
                int i3 = 0;
                while (true) {
                    if (i3 >= length2) {
                        break;
                    }
                    int index = ObjectUtil.getInt(split[i3], 0) - 1;
                    if (index < 0 || index >= newResult.size() || ReportService.REPORT_STATE_SUCCESS.equals(newResult.get(index))) {
                        i3++;
                    } else {
                        b2 = false;
                        break;
                    }
                }
                if (!b2) {
                    i2++;
                } else {
                    score = 5;
                    break;
                }
            }
        }
        if (score == null) {
            score = Integer.valueOf(checkedNum == newResult.size() ? 5 : checkedNum > 0 ? 1 : 0);
        }
        this.gradeMapper.updResult2(id, StringUtils.join(newResult, "|"), score, desct, (String) null);
    }

    private boolean calcToolResult0(Integer devid, List<String> names, List<String> nameTypes) throws Exception {
        int num = 0;
        if (names.size() > 0) {
            num = this.gradeMapper.calcToolResult0(devid, names, false);
        }
        if (num == 0 && nameTypes.size() > 0) {
            num = this.gradeMapper.calcToolResult0(devid, nameTypes, true);
        }
        return num <= 0;
    }

    private boolean calcToolResult1(Integer devid, List<String> names, List<String> nameTypes) throws Exception {
        int num = 0;
        if (names.size() > 0) {
            num = this.gradeMapper.calcToolResult1(devid, names, false);
        }
        if (num == 0 && nameTypes.size() > 0) {
            num = this.gradeMapper.calcToolResult1(devid, nameTypes, true);
        }
        return num <= 0;
    }

    private boolean calcToolResult2(Integer devid, List<String> names) throws Exception {
        int num = 0;
        if (names.size() > 0) {
            num = this.gradeMapper.calcToolResult2(devid, names);
        }
        return num <= 0;
    }

    private boolean calcToolResult3(Integer devid) throws Exception {
        int num = this.gradeMapper.calcToolResult3(devid);
        return num <= 0;
    }

    private boolean calcToolResult4(Integer devid, List<String> names, List<String> nameTypes) throws Exception {
        int num = 0;
        if (names.size() > 0) {
            num = this.gradeMapper.calcToolResult4(devid, names, false);
        }
        if (num == 0 && nameTypes.size() > 0) {
            num = this.gradeMapper.calcToolResult4(devid, nameTypes, true);
        }
        return num <= 0;
    }

    private boolean calcToolResult5(Integer devid) throws Exception {
        int num = this.gradeMapper.calcToolResult5(devid);
        return num <= 0;
    }

    private boolean calcToolResult7(Integer devid) throws Exception {
        int num = this.gradeMapper.calcToolResult7(devid);
        return num <= 0;
    }

    private String get2007Value(XSSFCell cell) {
        String value = "";
        if (cell != null) {
            switch (cell.getCellType()) {
                case 0:
                    if (DateUtil.isCellDateFormatted(cell)) {
                        value = new SimpleDateFormat("yyyy/MM/dd").format(cell.getDateCellValue());
                        break;
                    } else {
                        value = new DecimalFormat("#").format(cell.getNumericCellValue());
                        break;
                    }
                case 1:
                    value = cell.getRichStringCellValue().toString();
                    break;
                case 2:
                    value = String.valueOf(cell.getCellFormula());
                    break;
                case 3:
                    value = String.valueOf(cell.getRichStringCellValue().toString());
                    break;
                case 4:
                    value = String.valueOf(cell.getBooleanCellValue());
                    break;
                case 5:
                    value = String.valueOf((int) cell.getErrorCellValue());
                    break;
            }
        }
        return value.trim();
    }

    private List<String[]> readXlsx(XSSFSheet hssfSheet, int startRow, int cols, Integer maxRow, int[] requCols) {
        List<String[]> list = new ArrayList<>();
        if (hssfSheet != null) {
            loop0: for (int rowNum = startRow; rowNum <= hssfSheet.getLastRowNum() && (maxRow == null || list.size() < maxRow.intValue()); rowNum++) {
                XSSFRow hssfRow = hssfSheet.getRow(rowNum);
                if (hssfRow != null) {
                    String[] row = new String[cols];
                    for (int i = 0; i < cols; i++) {
                        row[i] = get2007Value(hssfRow.getCell(i));
                    }
                    int length = requCols.length;
                    int i2 = 0;
                    while (true) {
                        if (i2 < length) {
                            int col = requCols[i2];
                            if (row[col].length() == 0) {
                                break loop0;
                            }
                            i2++;
                        } else {
                            boolean emptyRow = true;
                            int length2 = row.length;
                            int i3 = 0;
                            while (true) {
                                if (i3 >= length2) {
                                    break;
                                }
                                String col2 = row[i3];
                                if (col2.length() == 0) {
                                    i3++;
                                } else {
                                    emptyRow = false;
                                    break;
                                }
                            }
                            if (emptyRow) {
                                break;
                            }
                            list.add(row);
                        }
                    }
                }
            }
        }
        return list;
    }

    private Map<String, String> readXlsx(XSSFSheet hssfSheet, int startRow, int endRow) {
        Map<String, String> r = new HashMap<>();
        if (hssfSheet != null) {
            for (int rowNum = startRow; rowNum <= endRow; rowNum++) {
                XSSFRow hssfRow = hssfSheet.getRow(rowNum);
                if (hssfRow != null) {
                    String name = get2007Value(hssfRow.getCell(0));
                    String value = get2007Value(hssfRow.getCell(1));
                    if (name.length() > 0) {
                        r.put(name, value);
                    }
                }
            }
        }
        return r;
    }

    private void importCjb1(HttpSession session, XSSFWorkbook hssfWorkbook) throws Exception {
        Map<String, String> infosys = readXlsx(hssfWorkbook.getSheetAt(0), 1, 6);
        if (!infosys.containsKey("信息系统名称*") || !infosys.containsKey("SAG等级*")) {
            throw new UEException("信息系统名称及安全等级必须填写");
        }
        Map<String, String> cpdw = readXlsx(hssfWorkbook.getSheetAt(0), 9, 17);
        if (!cpdw.containsKey("单位名称*")) {
            throw new UEException("单位名称必须填写");
        }
        List<String[]> aqfw = readXlsx(hssfWorkbook.getSheetAt(1), 2, 2, 20, new int[1]);
        List<String[]> jf = readXlsx(hssfWorkbook.getSheetAt(2), 2, 3, 20, new int[1]);
        List<String[]> ftry = readXlsx(hssfWorkbook.getSheetAt(3), 2, 2, 20, new int[1]);
        List<String[]> aqxgry = readXlsx(hssfWorkbook.getSheetAt(4), 2, 3, 20, new int[1]);
        List<String[]> gjsjlb = readXlsx(hssfWorkbook.getSheetAt(5), 2, 4, 20, new int[1]);
        List<String[]> aqsb = readXlsx(hssfWorkbook.getSheetAt(6), 2, 7, 20, new int[]{0, 2});
        List<String[]> wlsb = readXlsx(hssfWorkbook.getSheetAt(7), 2, 7, 20, new int[]{0, 2});
        List<String[]> fwqccsb = readXlsx(hssfWorkbook.getSheetAt(8), 2, 6, 20, new int[1]);
        List<String[]> zd = readXlsx(hssfWorkbook.getSheetAt(9), 2, 5, 20, new int[]{0, 2});
        List<String[]> ywyyrj = readXlsx(hssfWorkbook.getSheetAt(10), 2, 5, 20, new int[]{0, 1});
        List<String[]> sjkglxt = readXlsx(hssfWorkbook.getSheetAt(11), 2, 5, 20, new int[]{0, 1});
        List<String[]> aqglwd = readXlsx(hssfWorkbook.getSheetAt(12), 2, 2, 20, new int[1]);
        User user = (User) session.getAttribute("userInfo");
        Integer sysid = add(infosys.get("信息系统名称*"), infosys.get("SAG等级*"), cpdw.get("单位名称*"), infosys.get("系统简介"), infosys.get("承载的业务情况"), infosys.get("前次测评情况"), user.getId());
        if (aqfw.size() > 0) {
            for (String[] row : aqfw) {
                this.reportMapper.addSecser(sysid, row[0], row[1]);
            }
        }
        if (jf.size() > 0) {
            for (String[] row2 : jf) {
                Map<String, Object> params = new HashMap<>();
                params.put("sysid", sysid);
                params.put("type", "机房");
                params.put("ischeck", 1);
                params.put("host_name", row2[0]);
                params.put("host_location", row2[1]);
                params.put("host_impo", Integer.valueOf(row2[2].contains("非常") ? 1 : row2[2].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params);
                String layer = (String) LAYER_ENTRY.get("机房");
                if (layer != null) {
                    Integer devid = ObjectUtil.getInt(params.get("id"));
                    String sag = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
                    this.gradeMapper.createInfosysItems(sysid, sag, devid, layer);
                }
            }
        }
        if (ftry.size() > 0) {
            Iterator<String[]> it = ftry.iterator();
            while (it.hasNext()) {
                Object[] row3 = (String[]) it.next();
                Map<String, Object> params2 = new HashMap<>();
                params2.put("sysid", sysid);
                params2.put("type", "访谈人员");
                params2.put("ischeck", 1);
                params2.put("interv_name", row3[0]);
                params2.put("interv_job", row3[1]);
                this.gradeMapper.addDev(params2);
            }
        }
        if (aqxgry.size() > 0) {
            Iterator<String[]> it2 = aqxgry.iterator();
            while (it2.hasNext()) {
                Object[] row4 = (String[]) it2.next();
                Map<String, Object> params3 = new HashMap<>();
                params3.put("sysid", sysid);
                params3.put("type", "安全相关人员");
                params3.put("ischeck", 0);
                params3.put("user_name", row4[0]);
                params3.put("user_job", row4[1]);
                params3.put("user_concat", row4[2]);
                this.gradeMapper.addDev(params3);
            }
        }
        if (gjsjlb.size() > 0) {
            for (String[] row5 : gjsjlb) {
                Map<String, Object> params4 = new HashMap<>();
                params4.put("sysid", sysid);
                params4.put("type", "关键数据类别");
                params4.put("ischeck", 0);
                params4.put("data_type", row5[0]);
                params4.put("data_app", row5[1]);
                params4.put("data_secu", row5[2]);
                params4.put("data_impo", Integer.valueOf(row5[3].contains("非常") ? 1 : row5[3].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params4);
            }
        }
        if (aqsb.size() > 0) {
            for (String[] row6 : aqsb) {
                Map<String, Object> params5 = new HashMap<>();
                params5.put("sysid", sysid);
                params5.put("type", "安全设备");
                params5.put("ischeck", 1);
                params5.put("net_ip", row6[0]);
                params5.put("net_name", row6[1]);
                params5.put("net_os", row6[2]);
                params5.put("net_brand", row6[3]);
                params5.put("net_type", row6[4]);
                params5.put("net_use", row6[5]);
                params5.put("net_impo", Integer.valueOf(row6[6].contains("非常") ? 1 : row6[6].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params5);
                String layer2 = (String) LAYER_ENTRY.get("安全设备");
                if (layer2 != null) {
                    Integer devid2 = ObjectUtil.getInt(params5.get("id"));
                    String sag2 = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
                    this.gradeMapper.createInfosysItems(sysid, sag2, devid2, layer2);
                }
            }
        }
        if (wlsb.size() > 0) {
            for (String[] row7 : wlsb) {
                Map<String, Object> params6 = new HashMap<>();
                params6.put("sysid", sysid);
                params6.put("type", "网络设备");
                params6.put("ischeck", 1);
                params6.put("net_ip", row7[0]);
                params6.put("net_name", row7[1]);
                params6.put("net_os", row7[2]);
                params6.put("net_brand", row7[3]);
                params6.put("net_type", row7[4]);
                params6.put("net_use", row7[5]);
                params6.put("net_impo", Integer.valueOf(row7[6].contains("非常") ? 1 : row7[6].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params6);
                String layer3 = (String) LAYER_ENTRY.get("网络设备");
                if (layer3 != null) {
                    Integer devid3 = ObjectUtil.getInt(params6.get("id"));
                    String sag3 = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
                    this.gradeMapper.createInfosysItems(sysid, sag3, devid3, layer3);
                }
            }
        }
        if (fwqccsb.size() > 0) {
            for (String[] row8 : fwqccsb) {
                Map<String, Object> params7 = new HashMap<>();
                params7.put("sysid", sysid);
                params7.put("type", "服务器/存储设备");
                params7.put("ischeck", 1);
                params7.put("ser_ip", row8[0]);
                params7.put("ser_name", row8[1]);
                params7.put("ser_os", row8[2]);
                params7.put("ser_ver", row8[3]);
                params7.put("ser_soft", row8[4]);
                params7.put("ser_impo", Integer.valueOf(row8[5].contains("非常") ? 1 : row8[5].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params7);
                String layer4 = (String) LAYER_ENTRY.get("服务器/存储设备");
                if (layer4 != null) {
                    Integer devid4 = ObjectUtil.getInt(params7.get("id"));
                    String sag4 = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
                    this.gradeMapper.createInfosysItems(sysid, sag4, devid4, layer4);
                }
            }
        }
        if (zd.size() > 0) {
            for (String[] row9 : zd) {
                Map<String, Object> params8 = new HashMap<>();
                params8.put("sysid", sysid);
                params8.put("type", "终端");
                params8.put("ischeck", 1);
                params8.put("term_ip", row9[0]);
                params8.put("term_name", row9[1]);
                params8.put("term_os", row9[2]);
                params8.put("term_use", row9[3]);
                params8.put("term_impo", Integer.valueOf(row9[4].contains("非常") ? 1 : row9[4].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params8);
                String layer5 = (String) LAYER_ENTRY.get("终端");
                if (layer5 != null) {
                    Integer devid5 = ObjectUtil.getInt(params8.get("id"));
                    String sag5 = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
                    this.gradeMapper.createInfosysItems(sysid, sag5, devid5, layer5);
                }
            }
        }
        if (ywyyrj.size() > 0) {
            for (String[] row10 : ywyyrj) {
                Map<String, Object> params9 = new HashMap<>();
                params9.put("sysid", sysid);
                params9.put("type", "业务应用软件");
                params9.put("ischeck", 1);
                params9.put("soft_ip", row10[0]);
                params9.put("soft_name", row10[1]);
                params9.put("soft_func", row10[2]);
                params9.put("soft_fact", row10[3]);
                params9.put("soft_impo", Integer.valueOf(row10[4].contains("非常") ? 1 : row10[4].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params9);
                String layer6 = (String) LAYER_ENTRY.get("业务应用软件");
                if (layer6 != null) {
                    Integer devid6 = ObjectUtil.getInt(params9.get("id"));
                    String sag6 = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
                    this.gradeMapper.createInfosysItems(sysid, sag6, devid6, layer6);
                }
            }
        }
        if (sjkglxt.size() > 0) {
            for (String[] row11 : sjkglxt) {
                Map<String, Object> params10 = new HashMap<>();
                params10.put("sysid", sysid);
                params10.put("type", "数据库管理系统");
                params10.put("ischeck", 1);
                params10.put("dbsys_ip", row11[0]);
                params10.put("dbsys_name", row11[1]);
                params10.put("dbsys_type", row11[2]);
                params10.put("dbsys_devname", row11[3]);
                params10.put("dbsys_impo", Integer.valueOf(row11[4].contains("非常") ? 1 : row11[4].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev(params10);
                String layer7 = (String) LAYER_ENTRY.get("数据库管理系统");
                if (layer7 != null) {
                    Integer devid7 = ObjectUtil.getInt(params10.get("id"));
                    String sag7 = String.valueOf(this.gradeMapper.getById(sysid).get("sag"));
                    this.gradeMapper.createInfosysItems(sysid, sag7, devid7, layer7);
                }
            }
        }
        if (aqglwd.size() > 0) {
            Iterator<String[]> it3 = aqglwd.iterator();
            while (it3.hasNext()) {
                Object[] row12 = (String[]) it3.next();
                Map<String, Object> params11 = new HashMap<>();
                params11.put("sysid", sysid);
                params11.put("type", "安全管理文档");
                params11.put("ischeck", 1);
                params11.put("doc_name", row12[0]);
                params11.put("doc_content", row12[1]);
                this.gradeMapper.addDev(params11);
            }
        }
    }

    private void importCjb2(HttpSession session, XSSFWorkbook hssfWorkbook) throws Exception {
        Map<String, String> infosys = readXlsx(hssfWorkbook.getSheetAt(0), 1, 7);
        if (ObjectUtil.getString(infosys.get("被测对象名称*"), (String) null) == null || ObjectUtil.getString(infosys.get("SAG等级*"), (String) null) == null) {
            throw new UEException("被测对象名称及SAG等级必须填写");
        }
        Map<String, String> cpdw = readXlsx(hssfWorkbook.getSheetAt(0), 10, 18);
        if (ObjectUtil.getString(cpdw.get("单位名称*"), (String) null) == null) {
            throw new UEException("被测单位名称必须填写");
        }
        List<String[]> jf = readXlsx(hssfWorkbook.getSheetAt(1), 2, 3, 20, new int[1]);
        List<String[]> aqsb = readXlsx(hssfWorkbook.getSheetAt(2), 2, 7, 20, new int[]{0, 3});
        List<String[]> wlsb = readXlsx(hssfWorkbook.getSheetAt(3), 2, 7, 20, new int[]{0, 3});
        List<String[]> fwqccsb = readXlsx(hssfWorkbook.getSheetAt(4), 2, 9, 20, new int[1]);
        List<String[]> zdxcsb = readXlsx(hssfWorkbook.getSheetAt(5), 2, 7, 20, new int[1]);
        List<String[]> xtglrjpt = readXlsx(hssfWorkbook.getSheetAt(6), 2, 6, 20, new int[1]);
        List<String[]> ywyyrjpt = readXlsx(hssfWorkbook.getSheetAt(7), 2, 5, 20, new int[1]);
        List<String[]> gjsjlb = readXlsx(hssfWorkbook.getSheetAt(8), 2, 5, 20, new int[1]);
        List<String[]> aqxgry = readXlsx(hssfWorkbook.getSheetAt(9), 2, 3, 20, new int[1]);
        List<String[]> aqglwd = readXlsx(hssfWorkbook.getSheetAt(10), 2, 2, 20, new int[1]);
        User user = (User) session.getAttribute("userInfo");
        String ext = ObjectUtil.getString(infosys.get("等级保护对象形态"), "");
        Integer ext_cloud = Integer.valueOf(ext.contains("云") ? 1 : 0);
        Integer ext_mobile = Integer.valueOf(ext.contains("移动") ? 1 : 0);
        Integer ext_iot = Integer.valueOf(ext.contains("物") ? 1 : 0);
        Integer ext_ic = Integer.valueOf(ext.contains("工业") ? 1 : 0);
        Integer ext_bdata = Integer.valueOf(ext.contains("大数据") ? 1 : 0);
        Integer ext_other = Integer.valueOf((ext.contains("其他系统") || ext.contains("其它系统")) ? 1 : 0);
        Integer sysid = add2(infosys.get("被测对象名称*"), infosys.get("SAG等级*"), cpdw.get("单位名称*"), infosys.get("被测对象描述"), infosys.get("业务和采用的技术"), infosys.get("前次测评情况"), ext_cloud, ext_mobile, ext_iot, ext_ic, ext_bdata, ext_other, user.getId());
        if (jf.size() > 0) {
            for (String[] row : jf) {
                Map<String, Object> params = new HashMap<>();
                params.put("sysid", sysid);
                params.put("type", "物理机房");
                params.put("host_name", row[0]);
                params.put("host_location", row[1]);
                params.put("host_impo", Integer.valueOf(row[2].contains("非常") ? 1 : row[2].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params);
                String layer = (String) LAYER_ENTRY2.get("物理机房");
                if (layer != null) {
                    Integer devid = ObjectUtil.getInt(params.get("id"));
                    String sag = String.valueOf(this.gradeMapper.getById2(sysid).get("sag"));
                    this.gradeMapper.createInfosys2Items(sysid, sag, devid, layer, Boolean.valueOf(ext_cloud.intValue() == 1), Boolean.valueOf(ext_mobile.intValue() == 1), Boolean.valueOf(ext_iot.intValue() == 1), Boolean.valueOf(ext_ic.intValue() == 1));
                }
            }
        }
        if (aqsb.size() > 0) {
            for (String[] row2 : aqsb) {
                Map<String, Object> params2 = new HashMap<>();
                params2.put("sysid", sysid);
                params2.put("type", "安全设备");
                params2.put("net_ip", row2[0]);
                params2.put("net_name", row2[1]);
                params2.put("net_isvir", Integer.valueOf("是".equals(row2[2]) ? 1 : 0));
                params2.put("net_os", row2[3]);
                params2.put("net_brand", row2[4]);
                params2.put("net_use", row2[5]);
                params2.put("net_impo", Integer.valueOf(row2[6].contains("非常") ? 1 : row2[6].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params2);
                String layer2 = (String) LAYER_ENTRY2.get("安全设备");
                if (layer2 != null) {
                    Integer devid2 = ObjectUtil.getInt(params2.get("id"));
                    String sag2 = String.valueOf(this.gradeMapper.getById2(sysid).get("sag"));
                    this.gradeMapper.createInfosys2Items(sysid, sag2, devid2, layer2, Boolean.valueOf(ext_cloud.intValue() == 1), Boolean.valueOf(ext_mobile.intValue() == 1), Boolean.valueOf(ext_iot.intValue() == 1), Boolean.valueOf(ext_ic.intValue() == 1));
                }
            }
        }
        if (wlsb.size() > 0) {
            for (String[] row3 : wlsb) {
                Map<String, Object> params3 = new HashMap<>();
                params3.put("sysid", sysid);
                params3.put("type", "网络设备");
                params3.put("net_ip", row3[0]);
                params3.put("net_name", row3[1]);
                params3.put("net_isvir", Integer.valueOf("是".equals(row3[2]) ? 1 : 0));
                params3.put("net_os", row3[3]);
                params3.put("net_brand", row3[4]);
                params3.put("net_use", row3[5]);
                params3.put("net_impo", Integer.valueOf(row3[6].contains("非常") ? 1 : row3[6].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params3);
                String layer3 = (String) LAYER_ENTRY2.get("网络设备");
                if (layer3 != null) {
                    Integer devid3 = ObjectUtil.getInt(params3.get("id"));
                    String sag3 = String.valueOf(this.gradeMapper.getById2(sysid).get("sag"));
                    this.gradeMapper.createInfosys2Items(sysid, sag3, devid3, layer3, Boolean.valueOf(ext_cloud.intValue() == 1), Boolean.valueOf(ext_mobile.intValue() == 1), Boolean.valueOf(ext_iot.intValue() == 1), Boolean.valueOf(ext_ic.intValue() == 1));
                }
            }
        }
        if (fwqccsb.size() > 0) {
            for (String[] row4 : fwqccsb) {
                Map<String, Object> params4 = new HashMap<>();
                params4.put("sysid", sysid);
                params4.put("type", "服务器/存储设备");
                params4.put("ser_ip", row4[0]);
                params4.put("ser_name", row4[1]);
                params4.put("ser_ptname", row4[2]);
                params4.put("ser_isvir", Integer.valueOf("是".equals(row4[3]) ? 1 : 0));
                params4.put("ser_os", row4[4]);
                params4.put("ser_dbsys", row4[5]);
                params4.put("ser_mld", row4[6]);
                params4.put("ser_desct", row4[7]);
                params4.put("ser_impo", Integer.valueOf(row4[8].contains("非常") ? 1 : row4[8].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params4);
                String layer4 = (String) LAYER_ENTRY2.get("服务器/存储设备");
                if (layer4 != null) {
                    Integer devid4 = ObjectUtil.getInt(params4.get("id"));
                    String sag4 = String.valueOf(this.gradeMapper.getById2(sysid).get("sag"));
                    this.gradeMapper.createInfosys2Items(sysid, sag4, devid4, layer4, Boolean.valueOf(ext_cloud.intValue() == 1), Boolean.valueOf(ext_mobile.intValue() == 1), Boolean.valueOf(ext_iot.intValue() == 1), Boolean.valueOf(ext_ic.intValue() == 1));
                }
            }
        }
        if (zdxcsb.size() > 0) {
            for (String[] row5 : zdxcsb) {
                Map<String, Object> params5 = new HashMap<>();
                params5.put("sysid", sysid);
                params5.put("type", "终端/现场设备");
                params5.put("term_ip", row5[0]);
                params5.put("term_name", row5[1]);
                params5.put("term_isvir", Integer.valueOf("是".equals(row5[2]) ? 1 : 0));
                params5.put("term_os", row5[3]);
                params5.put("term_soft", row5[4]);
                params5.put("term_desct", row5[5]);
                params5.put("term_impo", Integer.valueOf(row5[6].contains("非常") ? 1 : row5[6].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params5);
                String layer5 = (String) LAYER_ENTRY2.get("终端/现场设备");
                if (layer5 != null) {
                    Integer devid5 = ObjectUtil.getInt(params5.get("id"));
                    String sag5 = String.valueOf(this.gradeMapper.getById2(sysid).get("sag"));
                    this.gradeMapper.createInfosys2Items(sysid, sag5, devid5, layer5, Boolean.valueOf(ext_cloud.intValue() == 1), Boolean.valueOf(ext_mobile.intValue() == 1), Boolean.valueOf(ext_iot.intValue() == 1), Boolean.valueOf(ext_ic.intValue() == 1));
                }
            }
        }
        if (xtglrjpt.size() > 0) {
            for (String[] row6 : xtglrjpt) {
                Map<String, Object> params6 = new HashMap<>();
                params6.put("sysid", sysid);
                params6.put("type", "系统管理软件/平台");
                params6.put("soft_name", row6[0]);
                params6.put("soft_devname", row6[1]);
                params6.put("soft_version", row6[2]);
                params6.put("soft_func", row6[3]);
                params6.put("soft_desct", row6[4]);
                params6.put("soft_impo", Integer.valueOf(row6[5].contains("非常") ? 1 : row6[5].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params6);
            }
        }
        if (ywyyrjpt.size() > 0) {
            for (String[] row7 : ywyyrjpt) {
                Map<String, Object> params7 = new HashMap<>();
                params7.put("sysid", sysid);
                params7.put("type", "业务应用软件/平台");
                params7.put("app_name", row7[0]);
                params7.put("app_func", row7[1]);
                params7.put("app_soft", row7[2]);
                params7.put("app_compnay", row7[3]);
                params7.put("app_impo", Integer.valueOf(row7[4].contains("非常") ? 1 : row7[4].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params7);
            }
        }
        if (gjsjlb.size() > 0) {
            for (String[] row8 : gjsjlb) {
                StringBuffer dataApp = new StringBuffer();
                String[] arr = {"采集", "存储", "处理", "应用", "流动", "销毁"};
                for (int i = 0; i < arr.length; i++) {
                    if (row8[2] != null && row8[2].contains(arr[i])) {
                        dataApp.append('/');
                        dataApp.append(i + 1);
                    }
                }
                if (dataApp.length() > 0) {
                    dataApp.deleteCharAt(0);
                }
                Map<String, Object> params8 = new HashMap<>();
                params8.put("sysid", sysid);
                params8.put("type", "关键数据类别");
                params8.put("data_type", row8[0]);
                params8.put("data_level", row8[1]);
                params8.put("data_app", dataApp.toString());
                params8.put("data_secu", row8[3]);
                params8.put("data_impo", Integer.valueOf(row8[4].contains("非常") ? 1 : row8[4].contains("比较") ? 2 : 3));
                this.gradeMapper.addDev2(params8);
            }
        }
        if (aqxgry.size() > 0) {
            Iterator<String[]> it = aqxgry.iterator();
            while (it.hasNext()) {
                Object[] row9 = (String[]) it.next();
                Map<String, Object> params9 = new HashMap<>();
                params9.put("sysid", sysid);
                params9.put("type", "安全相关人员");
                params9.put("user_name", row9[0]);
                params9.put("user_job", row9[1]);
                params9.put("user_concat", row9[2]);
                this.gradeMapper.addDev2(params9);
            }
        }
        if (aqglwd.size() > 0) {
            Iterator<String[]> it2 = aqglwd.iterator();
            while (it2.hasNext()) {
                Object[] row10 = (String[]) it2.next();
                Map<String, Object> params10 = new HashMap<>();
                params10.put("sysid", sysid);
                params10.put("type", "安全管理文档");
                params10.put("doc_name", row10[0]);
                params10.put("doc_content", row10[1]);
                this.gradeMapper.addDev2(params10);
            }
        }
    }
}
